==> removedrive-1.0.0.tgz: package/tests/removedrive.spec.js <==
var m = require('mochainon');
var _ = require('lodash');
var child_process = require('child_process');
var removedrive = require('../lib/removedrive');

describe('RemoveDrive:', function() {

  describe('.eject()', function() {

    describe('given an error when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(new Error('script error'), '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield the error back', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.be.an.instanceof(Error);
          m.chai.expect(error.message).to.equal('script error');
          done();
        });
      });

    });

    describe('given stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', 'stderr');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield the stderr output as an error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.be.an.instanceof(Error);
          m.chai.expect(error.message).to.equal('stderr');
          done();
        });
      });

    });

    describe('given no error nor stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield no error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.not.exist;
          done();
        });
      });

      it('should call execFile once', function(done) {
        removedrive.eject('D', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub).to.have.been.calledOnce;
          done();
        }, this));
      });

    });

    describe('given only blank stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '    ');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield no error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.not.exist;
          done();
        });
      });

    });

    describe('given untrimmed stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '  stderr   ');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield a trimmed error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.be.an.instanceof(Error);
          m.chai.expect(error.message).to.equal('stderr');
          done();
        });
      });

    });

    describe('given a drive letter without a colon', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should attach the colon automatically', function(done) {
        removedrive.eject('D', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub.firstCall.args[1][0]).to.equal('D:');
          done();
        }, this));
      });

    });

    describe('given a drive letter with a colon', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should not attach another colon', function(done) {
        removedrive.eject('D:', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub.firstCall.args[1][0]).to.equal('D:');
          done();
        }, this));
      });

    });

  });

});

==> removedrive-1.1.2.tgz: package/tests/removedrive.spec.js <==
var m = require('mochainon');
var _ = require('lodash');
var child_process = require('child_process');
var drivelist = require('drivelist');
var removedrive = require('../lib/removedrive');

describe('RemoveDrive:', function() {

  this.timeout(10000);

  describe('.eject()', function() {

    describe('given an error when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(new Error('script error'), '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield the error back', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.be.an.instanceof(Error);
          m.chai.expect(error.message).to.equal('script error');
          done();
        });
      });

    });

    describe('given stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', 'stderr');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield the stderr output as an error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.be.an.instanceof(Error);
          m.chai.expect(error.message).to.equal('stderr');
          done();
        });
      });

    });

    describe('given no error nor stderr output when executing RemoveDrive.exe', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should yield no error', function(done) {
        removedrive.eject('D', function(error) {
          m.chai.expect(error).to.not.exist;
          done();
        });
      });

      it('should call execFile with the drive letter', function(done) {
        removedrive.eject('D', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub.secondCall.args[1]).to.deep.equal([ 'D:' ]);
          done();
        }, this));
      });

      describe('given a physical drive instead of a letter', function() {

        beforeEach(function() {
          this.drivelistListStub = m.sinon.stub(drivelist, 'list');
          this.drivelistListStub.yields(null, [
            { device: '\\\\.\\PHYSICALDRIVE1', mountpoint: 'C' },
            { device: '\\\\.\\PHYSICALDRIVE2', mountpoint: 'D' }
          ]);
        });

        afterEach(function() {
          this.drivelistListStub.restore();
        });

        it('should call RemoveDrive.exe with the drive letter if the physical drive exists', function(done) {
          removedrive.eject('\\\\.\\PHYSICALDRIVE2', function(error) {
            m.chai.expect(error).to.not.exist;
            m.chai.expect(this.childProcessExecFileStub.secondCall.args[1]).to.deep.equal([ 'D' ]);
            done();
          }.bind(this));
        });

        it('should yield an error if there is no drive letter', function(done) {
          removedrive.eject('\\\\.\\PHYSICALDRIVE9', function(error) {
            m.chai.expect(error).to.be.an.instanceof(Error);
            m.chai.expect(error.message).to.equal('Invalid drive: \\\\.\\PHYSICALDRIVE9');
            done();
          }.bind(this));
        });

      });

    });

    describe('given a drive letter without a colon', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should attach the colon automatically', function(done) {
        removedrive.eject('D', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub.secondCall.args[1][0]).to.equal('D:');
          done();
        }, this));
      });

    });

    describe('given a drive letter with a colon', function() {

      beforeEach(function() {
        this.childProcessExecFileStub = m.sinon.stub(child_process, 'execFile');
        this.childProcessExecFileStub.yields(null, '', '');
      });

      afterEach(function() {
        this.childProcessExecFileStub.restore();
      });

      it('should not attach another colon', function(done) {
        removedrive.eject('D:', _.bind(function(error) {
          m.chai.expect(error).to.not.exist;
          m.chai.expect(this.childProcessExecFileStub.secondCall.args[1][0]).to.equal('D:');
          done();
        }, this));
      });

    });

  });

});
